* cd /path/to/SupplementData/ 
use ./data/Data.dta, clear

set more 1

/*
***Dictionary of file data.dta****

session: Date and Time of the session.
Period: Each repetition of the game. In all sessions but the extended treatment there are 20 periods. In the Extended Treatment (E(1)) there are 30.
Treatment: Identifies the treatment
Environment: Classifies the environment, with R for the treatments in the Torus, P the treatments in the Plane and E the extended treatment.
roleType: Receiver (1), Sender (2)
n_roleID: roles (1: sender), (2, 3: receivers)
TreatmentRotation: Baseline of no rotation (1), Partially rotated (2), Fully rotated (3)
SenderTreatment: Idem as Treatment except that E(1) and R(1) are given the same code (3)
tr_R0 tr_R6 tr_R1 tr_P0 tr_P1 tr_E1: dummy variables for each treatment
subject_id: one id per subject who participated
n_state1, n_state2: state in each dimension (1,2) normalized to be between -180, 180.
n_messageA1, n_messageA2, n_messageB1, n_messageB2: message sent by each sender (A,B) in each dimension (1,2) normalized between -180, 180.
n_choice1, n_choice2: choice of the receiver in each dimension, normalized between -180, 180.
biasA1 biasB1 biasA2 biasB2: bias of each sender (A,B) in each dimension (1,2)   
*/


* ******************************************
* EXPORT DATA FOR MATHEMATICA 
* ******************************************
preserve
*Export Sender Level data to 
do ./scripts/ExportSenderData
restore
* Export Receiver-Linked Data
foreach TT in R0 R6 R1 P0 P1 E1 {
	preserve
	keep if tr_`TT'==1 	
	outsheet n_messageA1 n_messageA2 n_messageB1 n_messageB2 n_choice1 n_choice2 Period subject_id using "./data/csv`TT'.csv", comma nonames replace
	outsheet n_messageA1 n_messageA2 n_messageB1 n_messageB2 n_choice1 n_choice2 Period subject_id if Period<16  using "./data/csv`TT'_15.csv", comma nonames replace
	outsheet n_messageA1 n_messageA2 n_messageB1 n_messageB2 n_choice1 n_choice2 Period subject_id if Period>=16  using "./data/csv`TT'_L5.csv", comma nonames replace
	restore 
}
* ******************************************
* ******************************************

* Generate Treatment Label
label define Treatment 1 "R(0)"
label define Treatment 2 "R(.6)", add
label define Treatment 3 "R(1)", add
label define Treatment 4 "P(0)",add
label define Treatment 5 "P(1)",add
label define Treatment 6 "E(1)",add

label values Treatment Treatment

* ******************************************
* ******************************************
gen ActualDistance=sqrt(n_choice1^2+n_choice2^2)
gen ActualDistanceA=sqrt((n_choice1-biasA1)^2+(n_choice2-biasA2)^2)
gen ActualDistanceB=sqrt((n_choice1-biasB1)^2+(n_choice2-biasB2)^2)

gen ActualProfit=max(20- 8 * ActualDistance/45, 5)
gen ActualProfitA=max(20- 8* ActualDistanceA/45, 5)
gen ActualProfitB=max(20- 8 * ActualDistanceB/45, 5)

xtset subject_id Period

recode n_roleID (1=.) (2=1) (3=2), gen(SenderID)
gen SenderA=1 if SenderID==1
gen SenderB=1 if SenderID==2

gen distZ=sqrt(n_choice1^2+n_choice2^2)
gen Eff=1-distZ/137.736

gen Eff1=Eff==1

qui{
	foreach TT in 1 2 3 {
		foreach sender in A B {
		* NB Here we pool the E(1) first rounds into R(1)
			foreach issue in 1 2 {
			
				xtreg n_message`sender'`issue' if SenderTreatment==`TT' & Sender`sender'==1 & Period<=15, fe
				est sto m`sender'`issue'_`TT'
			}
			
			xtreg ActualProfit`sender' if SenderTreatment==`TT' & Sender`sender'==1 & Period<=15, fe
			est sto profit`sender'_`TT'
		}
	}
	foreach TT in 1 2 3  {
			foreach issue in 1 2 {
			
				xtreg n_choice`issue' if TreatmentRotation==`TT' & Environment==1 & roleType==1 , fe
				est sto z`issue'_`TT'
			}
			
			xtreg ActualProfit if TreatmentRotation==`TT' & Environment==1 & roleType==1 , fe
			est sto profit_`TT'
			
			xtreg Eff if TreatmentRotation==`TT' & Environment==1 & roleType==1, fe
			est sto eff_`TT'
			
			xtreg Eff1 if TreatmentRotation==`TT' & Environment==1 & roleType==1, fe
			est sto eff1_`TT'
		
	}	
}


* Summary Stat Table Estimates (Table II)
est tab mA1* ,  b(%9.1f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)
est tab mA2* ,  b(%9.1f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)

est tab mB1* ,  b(%9.1f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)
est tab mB2* ,  b(%9.1f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)

est tab z1* ,  b(%9.1f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)
est tab z2* ,  b(%9.1f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)

est tab profitA*,  b(%9.2f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)
est tab profitB*,  b(%9.2f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)
est tab profit_*,  b(%9.2f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)

est tab eff_*,  b(%9.3f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)
est tab eff1_*,  b(%9.3f) star(0.1 0.05 0.01) stats(sigma_u sigma_e N)

* Check Circular Correlations, test of Restriction A (details in footnote 17)
** Note this requires the circcorr command. run "net install circstat.pkg"
foreach T in 1 2 3 {
	foreach subject in A B {
		foreach issue in 1 2 {
			foreach message in 1 2 {
				disp "Treatment `T' ; State Issue `issue'; Message Issue `message'; sender `subject' "
				circcorr n_state`issue' n_message`subject'`message' if SenderTreatment==`T' & role==1 & Period<=15
			}
		}
	}
}

* Sender Figures and Histograms made in Mathematica
* Sender Exaggeration regressions are performed in Mathematica
* Receiver Efficiency CDFs and Barrett & Donald Estimation in Mathematica

preserve
*GMM Results (Table III)
drop if Period<16
drop if session=="110630_1612" | session=="110630_1417"

* ReNormalize All exaggerations so median is centered in the 360 degree wide region

foreach ss in A1 A2 B1 B2 {
	bysort Treatment: gen medExag`ss'=2*bias`ss'
	gen r_`ss'=mod(n_message`ss'+(180-medExag`ss'),360)-(180-medExag`ss')
}


gmm (EQ1: n_choice1-{alpha1}*n_messageA1 -(1-{alpha1})*n_messageB1-{beta1}*(n_messageB2-n_messageA2)-{gamma1}) (EQ2:n_choice2- {alpha2}*n_messageB2 -(1-{alpha2})*n_messageA2-{beta2}*(n_messageB1-n_messageA1)-{gamma2}) if Treatment==1 & Period>=16, instruments(n_messageA1 n_messageA2 n_messageB1 n_messageB2 ) winitial(identity) igmm
gmm (EQ1: n_choice1-{alpha1}*n_messageA1 -(1-{alpha1})*n_messageB1-{beta1}*(n_messageB2-n_messageA2)-{gamma1}) (EQ2:n_choice2- {alpha2}*n_messageB2 -(1-{alpha2})*n_messageA2-{beta2}*(n_messageB1-n_messageA1)-{gamma2}) if Treatment==2 & Period>=16, instruments(n_messageA1 n_messageA2 n_messageB1 n_messageB2 ) winitial(identity) igmm
gmm (EQ1: n_choice1-{alpha1}*n_messageA1 -(1-{alpha1})*n_messageB1-{beta1}*(n_messageB2-n_messageA2)-{gamma1}) (EQ2:n_choice2- {alpha2}*n_messageB2 -(1-{alpha2})*n_messageA2-{beta2}*(n_messageB1-n_messageA1)-{gamma2}) if Treatment==3 & Period>=16, instruments(n_messageA1 n_messageA2 n_messageB1 n_messageB2 ) winitial(identity) igmm


exit
 
